===============================
Django Tagulous - Fabulous Tags
===============================

Tagulous is a fully-featured tagging library for Django built on ``ForeignKey``
and ``ManyToManyField``, giving you all their normal power with a sprinkling of
tagging syntactic sugar, and a full set of extra
:doc:`features <introduction>`.


.. seealso::

    Read this online at http://radiac.net/projects/django-tagulous/


Contents
========

.. toctree::
    :maxdepth: 2

    introduction
    installation
    usage
    parser
    models/index
    forms
    tag_options
    views
    admin
    upgrading
    contributing
